<?php
/*
Plugin Name: Google +1 Button
Plugin URI: http://fabiolalli.com/google1button
Description: Adds a button which easily lets you +1 your blog posts.
Version: 1.1
Author: Fabio Lalli
Author URI: http://fabiolalli.com
*/

function google_options() {
	add_menu_page('Google1Button', 'Google1Button', 8, basename(__FILE__), 'google_options_page');
	add_submenu_page(basename(__FILE__), 'Google1Button', 'Google1Button', 8, basename(__FILE__), 'google_options_page');
}

/**
* Build up all the params for the button
*/
function google_build_options() {
	// get the post varibale (should be in the loop)
	global $post;

	// now build up the params, start with the source
    if (get_option('google_source')) {
        $button .= '&amp;source=' . urlencode(get_option('google_source'));
    }

	// which style
    if (get_option('google_version') == 'compact') {
        $button .= '&amp;style=compact';
    } else {
		$button .= '&amp;style=normal';
	}

	// what shortner to use
	if (get_option('google_url_shortner') && get_option('google_url_shortner') != 'default') {
    	$button .= '&amp;service=' . urlencode(get_option('google_url_shortner'));
	}

	// does the shortner have an API key
	if (get_option('google_api_key')) {
		$button .= '&amp;service_api=' . urlencode(get_option('google_api_key'));
	}

	// how many spaces do we want to leave at the end
	if (get_option('google_space')) {
		$button .= '&amp;space=' . get_option('google_space');
	}

	// append the hashtags
	if (get_option('google_hashtags') == 'yes') {
		// first lets see if the post has the custom field
		if (($hashtags = get_post_meta($post->ID, 'google_hashtags')) != false) {
			// first split them out
			$hashtags = explode(',', $hashtags[0]);
			// go through and urlencode
			foreach($hashtags as $row => $tag) {
				$hashtags[$row] = urlencode(trim($tag));
			}
			// nope so lets use them
			$button .= '&amp;hashtags=' . implode(',', $hashtags);
		} else if (($tags = get_the_tags()) != false) {
			// ok, grab them off the post tags
			$hashtags = array();
			foreach ($tags as $tag) {
				$hashtags[] = urlencode($tag->name);
			}
			$button .= '&amp;hashtags=' . implode(',', $hashtags);
		} else if (($hashtags = get_option('google_hashtags_tags')) != false) {
			// first split them out
			$hashtags = explode(',', $hashtags);
			// go through and urlencode
			foreach($hashtags as $row => $tag) {
				$hashtags[$row] = urlencode(trim($tag));
			}
			// add them all back together
			$button .= '&amp;hashtags=' . implode(',', $hashtags);
		}
	}

	$button .= '&amp;b=2';

	// return all the params
	return $button;
}

/**
* Generate the DIV and render of the button
*/
function google_generate_button() {

	global $post;
	// get the permalink
        if (get_post_status($post->ID) == 'publish') {
            $url = get_permalink();
        }

            // build up the outer style
        $button = '<div class="google_button" style="' . get_option('google_style') . '"><g:plusone size="tall"></g:plusone></div>';
            // return the iframe code
        return $button;
}

/**
* Generates the image button
*/
function google_generate_static_button() {
	if (get_post_status($post->ID) == 'publish') {
        $url = get_permalink();
		return
		'<div class="google_button" style="' . get_option('google_style') . '">
                    <g:plusone size="tall"></g:plusone>
		</div>';
	} else {
		return;
	}
}

/**
* Gets run when the content is loaded in the loop
*/
function google_update($content) {

    global $post;

	if (get_option('google_enable') == 'yes') {
		$button = google_generate_button();

	    // is it a page
	    if (get_option('google_display_page') == null && is_page()) {
	        return $content;
	    }
		// are we on the front page
	    if (get_option('google_display_front') == null) {
	        return $content;
	    }


            // are we just using the shortcode
            if (get_option('google_where') == 'shortcode') {
                    return str_replace('[google1button]', $button, $content);
            } else {
                    // if we have switched the button off
                    if (get_post_meta($post->ID, 'google') == null) {
                            if (get_option('google_where') == 'beforeandafter') {
                                    // adding it before and after
                                    return $button . $content . $button;
                            } else if (get_option('google_where') == 'before') {
                                    // just before
                                    return $button . $content;
                            } else {
                                    // just after
                                    return $content . $button;
                            }
                    } else {
                            // not at all
                            return $content;
                    }
            }
	} else {
		return $content;
	}
}

function google1button() {
    if (get_option('google_where') == 'manual') {
        return google_generate_button();
    } else {
        return false;
    }
}

function google_remove_filter($content) {
	if (!is_feed()) {
    	remove_action('the_content', 'google_update');
	}
    return $content;
}

function google_head() {
	// if its a post page
	if (is_single()) {
		global $post;
		$title = get_the_title($post->ID);
                echo '<script type="text/javascript" src="http://apis.google.com/js/plusone.js">';
                echo '  {lang: "it"}';
                echo '</script>';
	}
}
function google_footer() {
	
}


function google_options_page() {
?>
    <div class="wrap">
    <div class="icon32" id="icon-options-general"><br/></div><h2>Settings for Google +1 Button Integration</h2>
    <p>This plugin will install the Google +1 Button widget for each of your blog posts in both the content of your posts and the RSS feed.
    It can be easily styles in your blog posts.
    </p>
    <form method="post" action="options.php">
    <?php
        // New way of setting the fields, for WP 2.7 and newer
        if(function_exists('settings_fields')){
            settings_fields('google-options');
        } else {
            wp_nonce_field('update-options');
            ?>
            <input type="hidden" name="action" value="update" />
            <input type="hidden" name="page_options" value="google_ping,google_where,google_style,google_version,google_display_page,google_display_front,google_display_rss,google_display_feed,google_source,google_url_shortner,google_space,google_hashtags,google_hashtags_tags,google_api_key,google_enable" />
            <?php
        }
    ?>
        <table class="form-table">
            <tr>
	            <tr>
                        <th>Enable</th>
                        <td>
                            <input type="radio" value="yes" <?php if (get_option('google_enable') == 'yes' || !get_option('google_enable')) echo 'checked="checked"'; ?> name="google_enable" id="google_enable_yes" group="google_enable"/>
                            <label for="google_enable_yes">Yes</label>
                            <br/>
                            <input type="radio" value="no" <?php if (get_option('google_enable') == 'no') echo 'checked="checked"'; ?> name="google_enable" id="google_enable_no" group="google_enable" />
                            <label for="google_enable_no">No</label>
            		</td>
		    </tr>
	            <tr>
	                <th scope="row" valign="top">
	                    Display
	                </th>
	                <td>
	                    <input type="checkbox" value="1" <?php if (get_option('google_display_page') == '1') echo 'checked="checked"'; ?> name="google_display_page" id="google_display_page" group="google_display"/>
	                    <label for="google_display_page">Display the button on pages</label>
	                    <br/>
	                    <input type="checkbox" value="1" <?php if (get_option('google_display_front') == '1') echo 'checked="checked"'; ?> name="google_display_front" id="google_display_front" group="google_display"/>
	                    <label for="google_display_front">Display the button on the front page (home)</label>
	                </td>
	            </tr>
              <tr>
                <th scope="row" valign="top"><label for="twitter_style">Styling</label></th>
                <td>
                    <input type="text" value="<?php echo htmlspecialchars(get_option('google_style')); ?>" name="google_style" id="google_style" />
                    <span class="description">Add style to the div that surrounds the button E.g. <code>float: left; margin-right: 10px;</code></span>
                </td>
            </tr>
            <tr>
                <th scope="row" valign="top">
                    Position
                </th>
                <td>
                	<select name="google_where">
                		<option <?php if (get_option('google_where') == 'before') echo 'selected="selected"'; ?> value="before">Before</option>
                		<option <?php if (get_option('google_where') == 'after') echo 'selected="selected"'; ?> value="after">After</option>
                		<option <?php if (get_option('google_where') == 'beforeandafter') echo 'selected="selected"'; ?> value="beforeandafter">Before and After</option>
                	</select>
                </td>
            </tr>
           
        </table>
        <p class="submit">
            <input type="submit" name="Submit" value="<?php _e('Save Changes') ?>" />
        </p>
    </form>
    </div>
<?php
}

// On access of the admin page, register these variables (required for WP 2.7 & newer)
function google_init(){
    if(function_exists('register_setting')){
        register_setting('google-options', 'google_display_page');
        register_setting('google-options', 'google_display_front');
        register_setting('google-options', 'google_display_rss');
        register_setting('google-options', 'google_source', 'google_sanitize_username');
        register_setting('google-options', 'google_style');
        register_setting('google-options', 'google_version');
        register_setting('google-options', 'google_where');
        register_setting('google-options', 'google_rss_where');
        register_setting('google-options', 'google_ping');
        register_setting('google-options', 'google_url_shortner');
        register_setting('google-options', 'google_space');
        register_setting('google-options', 'google_hashtags');
        register_setting('google-options', 'google_hashtags_tags');
        register_setting('google-options', 'google_api_key');
        register_setting('google-options', 'google_enable');
    }
}

function google_sanitize_username($username){
    return preg_replace('/[^A-Za-z0-9_]/','',$username);
}

// Only all the admin options if the user is an admin
if(is_admin()){
    add_action('admin_menu', 'google_options');
    add_action('admin_init', 'google_init');
}

// Set the default options when the plugin is activated
function google_activate(){
    add_option('google_where', 'before');
    add_option('google_rss_where', 'before');
    add_option('google_source');
    add_option('google_style', 'float: right; margin-left: 10px;');
    add_option('google_version', 'large');
    add_option('google_display_page', '1');
    add_option('google_display_front', '1');
    add_option('google_display_rss', '0');
    add_option('google_ping', 'on');
    add_option('google_hashtags', 'off');
    add_option('google_enable', 'yes');
}

add_filter('the_content', 'google_update', 8);
add_filter('get_the_excerpt', 'google_remove_filter', 9);

add_action('wp_head', 'google_head');
add_action('wp_footer', 'google_footer');

register_activation_hook( __FILE__, 'google_activate');
